@@ -36,12 +36,12 @@ Configuration file for Home Site Maker
  - The [REQUIRED] variables should be modified with your own site values
  - You must to customize the variables identified with the [EDIT] tag
  - The [OPT] ones are optional, and you can leave they untouched
- - The [TRANS] tag is used when the only thing you need to do is translate the value to your own langauaje
+ - The [TRANS] tag is used when the only thing you need to do is to translate the value to your own langauaje
  - Don't edit the variables with the [STOP] comment if you don't know exactly what you are doing
 */
 
 
-$VERSION="homesitemaker-v0.4.2";                     // [STOP] Only for upgrading purporses
+$VERSION="homesitemaker-v0.4.5";                     // [STOP] Only for upgrading purporses
 $TITLE="Homesite Maker";                             // [EDIT] The title of your website
 $DESCRIPTION="The Homesite Maker project home page"; // [EDIT] A brief description of your website
 $URL="http://homesitemaker-devel-local.org";         // [REQUIRED] The URL used to serve your site
@@ -49,33 +49,35 @@ $URL="http://homesitemaker-devel-local.org";         // [REQUIRED] The URL used
 $SKIN="white_clouds"; // [OPT] Available skins are rainbow, aqua, simple, black-simple, black-grey and white_clouds
 $HEADER_WIDTH="90%";  // [OPT] Use porcentual value (%) or in pixels
 $BODY_WIDTH="90%";    // [OPT] Use porcentual value (%) or in pixels
-$LANGUAGE="english";  // [EDIT] Available languages are english, spanish and catalan (since 0.4.1 version).
-$EDITOR="both";       // [OPT] Availble values are: text-html, FCKeditor or both.
-                      //       text-html: compatible with all browsers.
-                      //       FCKeditor: WYSIWYG editor compatible only with
+$LANGUAGE="english";  // [EDIT] Available languages are english, spanish and catalan.
+$EDITOR="FCKeditor";  // [OPT] Availble values are: text-html, FCKeditor or both.
+                      // This option allows you to choose between different edition modes when you send news or edit infos.
+                      //       text-html: Send as HTML or Text compatible with all browsers but only for geeks visitors.
+                      //       FCKeditor: WYSIWYG editor. Usable for everybody, with or without HTML knowledge but, 
+                      //                  only compatible with the following browsers:
                       //                  IE 5.5+ (Windows), Firefox 1.0+, Mozilla 1.3+ and Netscape 7+ browsers.
-                      //                  Be sure that you have the fonts of FCKeditor in DocumentRoot/includes/FCKeditor
+                      //                  Be sure you have the sources of FCKeditor in DocumentRoot/includes/FCKeditor
+                      //                  if you install directly from the CVS sources.
                       //                  See www.fckeditor.net to know more about Frederico Caldeira Knabben editor (FCKeditor)
-                      //       both: The user can choose between both.
+                      //       both: The user can choose between WYSIWYG edition mode or HTML/Text mode.
 
-$RSS_LANG="es";       // [REQUIRED] Use only ISO 639 codes es, en, de, ca, etc.
-$RSS_ENCODING="ISO-8859-1"; //[STOP] If you have problems using UTF-8, use ISO-8859-1 instead
-$RSS_HISTORY="10";    // [OPT] Set the maximun number of news per XML/RSS feed file.
-$RSS_EDITOR="editor@something.com";          // [REQUIRED] Email address of person responsible for editorial content.
-$RSS_WEBMASTER="webmaster@something.com";    // [REQUIRED] Email address of person responsible for technical issues relating to channel
+$RSS_LANG="es";                            // [REQUIRED] Use only ISO 639 codes es, en, de, ca, etc.
+$RSS_ENCODING="ISO-8859-1";                //[STOP] If you have problems using UTF-8, use ISO-8859-1 instead
+$RSS_HISTORY="10";                         // [OPT] Set the maximun number of news per XML/RSS feed file.
+$RSS_EDITOR="editor@something.com";        // [REQUIRED] Email address of person responsible for editorial content.
+$RSS_WEBMASTER="webmaster@something.com";  // [REQUIRED] Email address of person responsible for technical issues relating to channel
 
-// MySQL database configuration values
-$DB_USER="homesite_user";      // [REQUIRED] The MySQL database user
-$DB_PASSWD="homesite_passwd";  // [REQUIRED] The MySQL user password
-$DB_NAME="homesite_db";        // [REQUIRED] The MySQL database name
+$DB_USER="homesite_user";                  // [REQUIRED] The MySQL database user
+$DB_PASSWD="homesite_passwd";              // [REQUIRED] The MySQL user password
+$DB_NAME="homesite_db";                    // [REQUIRED] The MySQL database name
 
-$DEFAULT_TAB="1";     // [OPT] Set the tab that shuold be on top when no one is selected (default option)
-$DEFAULT_SECTION="1"; // [OPT] Set the tab that shuold be on top when no one is selected (default option)
+$DEFAULT_TAB="1";     // [OPT] Set the tab that should be on top when no one is selected (default option)
+$DEFAULT_SECTION="1"; // [OPT] Set the tab that should be on top when no one is selected (default option)
 
 /* Set the title you wants for the main sections (tabs) and subsections (sections)
    There are 4 section types for the SECTION_TYPE variable.
-      info  -> It Allows you to edit the content of one static page in a easy way, allowing you to attach images
-      news  -> It Allows you to send news with attached images and post comments
+      info  -> Allows you to edit the content of one static page in a easy way, allowing you to attach images
+      news  -> Allows you to send news with attached images and post comments
       album -> A management system for your image albums with full access control system.
       diary -> Not already finished
       NO    -> Hide, no section is showed */
@@ -104,7 +106,7 @@ $TAB_34="NO";             $SECTION_TYPE_34="NO";      // [EDIT][EDIT] Title and
 $TAB_41="FAQs";           $SECTION_TYPE_41="info";    // [EDIT][EDIT] Title and type of the section 1 of the tab 4
 $TAB_42="Handbook";       $SECTION_TYPE_42="info";    // [EDIT][EDIT] Title and type of the section 2 of the tab 4
 $TAB_43="NO";             $SECTION_TYPE_43="NO";      // [EDIT][EDIT] Title and type of the section 3 of the tab 4
-$TAB_44="NO";             $SECTION_TYPE_44="NO";    // [EDIT][EDIT] Title and type of the section 4 of the tab 4
+$TAB_44="NO";             $SECTION_TYPE_44="NO";      // [EDIT][EDIT] Title and type of the section 4 of the tab 4
 
 $TAB_51="Users";          $SECTION_TYPE_51="users";   // [TRANS][STOP] Don't touch this if you don't know what you are doing
 $TAB_52="Config";         $SECTION_TYPE_52="config";  // [TRANS][STOP] Don't touch this if you don't know what you are doing
@@ -115,23 +117,24 @@ $P_ITEMS="YES";           // [OPT] If you wants to show pending items to be publ
 $STATS="YES";             // [OPT] If you wants to show some stats in the left pannel say yes here.
 
 
-// The following tags allows you to put HTML code in every of the six empty boxes of the webpage.
-// All of them are optional [OPT] but can be usefull to modify the look and feel of your website.
-// As you can see in the example, you can use the <img> tag in order to put an image inside it.
-// The COLOR_BOX and SKIN_BOX variables, allows to apply diferrent color (depending on the skin)
-// and the skin used to build the box. If you say NO in the SKIN_BOX, then the box will be displayed 
-// without borders.
-//
-//$SIZE_BOX[n]  To modify the height of the box[n]. Range 1-n (Default 90). 
-//              If SIZE_BOX[n]=0 the box is not displayed
-//$SKIN_BOX[n]  You can use different skins for every box. See the comment $SKIN at the beginning 
-//              of this file for available skins list.
-//              Furthermore you can say "NO" for drawing borderless boxes.
-//$COLOR_BOX[n] Depending on the skin you choose, you can select between
-//              up to four (B,Y,M,G) different colors for every box.
-//              You can use also color codes like #nnnnn. It's useful to integrate
-//              special borderless boxes with the background color and SKIN_BOX[n]="NO")
-//$LOGO_BOX[n] Use LOGO_BOX to add content (text or images) into the boxes (HTML tags are allowed)
+/* The following tags allows you to put HTML code in every of the six empty boxes of the webpage.
+   All of them are optional [OPT] but can be usefull to modify the look and feel of your website.
+   As you can see in the example, you can use the HTML <img> tag in order to put an image inside it.
+   The COLOR_BOX and SKIN_BOX variables, allows to apply diferrent color (depending on the skin)
+   and the skin used to build the box respectively. If you say NO in the SKIN_BOX, then the box will be 
+   displayed without borders.
+
+   $SIZE_BOX[n]  To modify the height of the box[n]. Range 1-n (Default 90).
+                 If SIZE_BOX[n]=0 the box is not displayed
+   $SKIN_BOX[n]  You can use different skins for every box. See the comment $SKIN at the beginning
+                 of this file for available skins list.
+                 Furthermore you can say "NO" for drawing borderless boxes.
+   $COLOR_BOX[n] Depending on the skin you choose, you can select between
+                 up to four (B,Y,M,G) different colors for every box.
+                 You can use also color codes like #nnnnn. It's useful to integrate
+                 special borderless boxes with the background color and SKIN_BOX[n]="NO")
+   $LOGO_BOX[n]  Use LOGO_BOX to add content (text or images) into the boxes (HTML tags are allowed) 
+                 DON'T FORGET TO ESCAPE THE DOUBLE QUOTES WHEN YOU TYPE HTML CODE!!! */
 
 $SIZE_BOX1="90";
 $WIDTH_BOX1="15%";
