@@ -54,7 +54,7 @@ $TEXT014="Totes les entradas de la base de dades relatives a aquesta informaci&o
 $TEXT015="La teva not&iacute;cia a sigut emmagatzemada".
          "Si tot es correcte, ser&agrave; publicada per un dels nostres editors tan aviat como sigui possible.";
 
-$TEXT016="L'usuari s'ha creat correctament. Ahora ja pots validar-te com usuari registrat";
+$TEXT016="L'usuari s'ha creat correctament. Ara ja pots validar-te com usuari registrat";
 $TEXT017="La teva petici&oacute; ha sigut processada.";
 
 $TEXT018="Usuari no v&agrave;lid! No pots realitzar aquesta operaci&oacute;.<br>".
