@@ -46,19 +46,12 @@ $TEXT012="Total";
 $TEXT013="Data d'Edici&oacute;";
 $TEXT014="Autor";
 $TEXT015="Titular";
-$TEXT048="Text Introductori";
 $TEXT016="Text";
-$TEXT049="Si est&agraves editant una not&iacute;cia molt llarga, quedar&agrave; millor si la divideixes en duess parts.<br>".
-         "Utilitza el quadre d'edici&oacute; \"$TEXT048\" per introduir-la i el quadre \"$TEXT016\" per la resta.";
 $TEXT017="Si env&iacute;es com HTML, llavors les etiquetes ser&agrave;n interpretades";
-$TEXT045="Enviar com:";
-$TEXT046="Text pla";
-$TEXT047="HTML";
-
 $TEXT018="Aquesta es la llista amb les fotos que hi ha actualment per a aquesta not&iacute;cia.<br>".
          "Pots seleccionar aquelles que vulguis esborrar<br>".
          "Si pel contrari vols afegir un altre imatge a aquesta not&iacute;cia,".
-	 "llavors selecciona-la desde el dia Adjuntar Foto";
+         "llavors selecciona-la desde el dia Adjuntar Foto";
 
 $TEXT019="Esborrar";
 $TEXT020="Nom d'Arxiu";
@@ -101,13 +94,21 @@ $TEXT042="T&iacute;tol del comentari";
 $TEXT043="Text del comentari";
 $TEXT044="<br>No tens permisos suficients per publicar not&iacute;cias pendents!<br><br>".
          "Si vols ser editor, envia un email l&agrave;dministrador del web.<br>&nbsp;";
-$TEXT054="<br>No tens permisos suficients per editar not&iacute;cias d'altes usuaris!<br><br>".
-         "Si vols ser editor, envia un email l&agrave;dministrador del web.<br>&nbsp;";
-$TEXT055="<br>No tens permisos suficients per esborrar not&iacute;cies !<br><br>".
-         "Si vols ser editor, envia un email l&agrave;dministrador del web.<br>&nbsp;";
+$TEXT045="Enviar com:";
+$TEXT046="Text pla";
+$TEXT047="HTML";
+$TEXT048="Text Introductori";
+$TEXT049="Si est&agraves editant una not&iacute;cia molt llarga, quedar&agrave; millor si la divideixes en duess parts.<br>".
+         "Utilitza el quadre d'edici&oacute; \"$TEXT048\" per introduir-la i el quadre \"$TEXT016\" per la resta.";
 $TEXT050="Llegir mes";
 $TEXT051="paraules";
 $TEXT052="$TITLE RSS 2.0 Feeds ";
 $TEXT053="Subscriu-te als feeds de $TITLE. Actualment, estan disponibles els seg&uuml;ents canals de not&iacutecies:";
-$TEXT054="Tots els feeds d&agrave;aquesta web han estat comprovats mitjan?ant";
+$TEXT054="<br>No tens permisos suficients per editar not&iacute;cias d'altes usuaris!<br><br>".
+         "Si vols ser editor, envia un email l&agrave;dministrador del web.<br>&nbsp;";
+$TEXT055="<br>No tens permisos suficients per esborrar not&iacute;cies !<br><br>".
+         "Si vols ser editor, envia un email l&agrave;dministrador del web.<br>&nbsp;";
+$TEXT056="Tots els feeds d&agrave;aquesta web han estat comprovats mitjan?ant";
+$TEXT057="Escriu aqu&iacute; el teu comentari !";
+$TEXT058="Escriu aqu&iacute; el teu texte !";
 ?>
