@@ -35,11 +35,9 @@ $TEXT001="Enviar";
 $TEXT002="Publicado el";
 $TEXT003="por";
 $TEXT004="Editado por &uacute;ltima vez";
-
 $TEXT005="Secci&oacute;n vacia !<br>".
          "Quizas quieras añadir algo de información aqu&iacute;.<br>".
          "De lo contrario deberias borrar esta secci&oacute;n.";
-
 $TEXT006="Comentarios";
 $TEXT007="Enviar comentario";
 $TEXT008="Editar";
@@ -50,20 +48,12 @@ $TEXT012="Total";
 $TEXT013="Fecha de Edici&oacute;n";
 $TEXT014="Autor";
 $TEXT015="Titular";
-$TEXT048="Texto Introductorio";
 $TEXT016="Texto";
-$TEXT049="Si estas editando una noticia muy larga, quedar&aacute; mejor si la divides en dos partes.<br>".
-         "Utiliza el cuadro de edici&oacute;n \"$TEXT048\" para introducirla y el cuadro \"$TEXT016\" para el resto.";
 $TEXT017="Si env&iacute;as como HTML, entonces las etiquetas ser&aacute;n interpretadas";
-$TEXT045="Enviar como:";
-$TEXT046="Texto plano";
-$TEXT047="HTML";
-
 $TEXT018="Esta es la lista con las fotos que hay actualmente para esta noticia.<br>".
          "Puedes selecciona aquellas que quieras borrar.<br>".
          "Si por el contrario deseas a&ntilde;adir otra imagen a esta noticia, ".
          "entonces seleccionala a desde el di&aacute; Adjuntar Foto.";
-
 $TEXT019="Borrar";
 $TEXT020="Nombre de Archivo";
 $TEXT021="Id. Foto";
@@ -74,29 +64,22 @@ $TEXT025="Previsualizar"; // See homesite-includes-dbwa.pnp before translate thi
 $TEXT026="Publicar";      // See homesite-includes-dbwa.pnp before translate this
 $TEXT027="Fecha de Env&iacute;o";
 $TEXT028="Titular";
-
 $TEXT029="La siguiente es la lista de noticias que est&aacute;n pendientes de tu aprovaci&oacute;n. ".
          "Si puedes ver esta lista, entonces es que dispones de los privilegios suficientes para hacerlo.<br>".
          "Puedes borrar directamente una noticia pulsando sobre la opci&oacute;n Borrar.<br>".
          "En caso contrario, pulsa sobre el titulo del album que desees editar y/o publicar.";
-
 $TEXT030="Id.Info";
 $TEXT031="Fecha";
 $TEXT032="No hay noticias pendientes de ser publicadas.";
 $TEXT033="Fecha de Borrado";
-
 $TEXT034="La noticia seleccionada ser&aacute; eliminada si continuas.<br><br>".
          "Est&aacute; usted competamente seguro ?";
-
 $TEXT035="Secci&oacute;n vacia !<br>".
          "Tal vez desee a&ntilde;adir algo de informaci&oacute;n aqu&iacute;.<br>".
          "De lo contrario, deber&iacute;as borrar esta secci&oacute;n.";
-
 $TEXT036="Comentar esta noticia";
-
 $TEXT037="Los comentarios siguientes son resposabilidad de quienes los hayan puesto. ".
          "De ninguna manera nos hacemos responsables de ninguno de ellos. ";
-
 $TEXT038="Responder a este comentario";
 $TEXT039="Respuesta con el t&iacute;tulo";
 $TEXT040="Est&aacute;s comentando esta noticia";
@@ -105,13 +88,21 @@ $TEXT042="T&iacute;tulo del comentario";
 $TEXT043="Texto del comentario";
 $TEXT044="<br>No tienes permisos suficientes para publicar noticias pendientes!<br><br>".
          "Si deseas llegar a ser editor, env&iacute;a un email al administrador del site.<br>&nbsp;";
-$TEXT054="<br>No tienes permisos suficientes para editar noticias de otros usuarios!<br><br>".
-         "Si deseas llegar a ser editor, env&iacute;a un email al administrador del site.<br>&nbsp;";
-$TEXT055="<br>No tienes permisos suficientes para borrar noticias !<br><br>".
-         "Si deseas llegar a ser editor, env&iacute;a un email al administrador del site.<br>&nbsp;";
+$TEXT045="Enviar como:";
+$TEXT046="Texto plano";
+$TEXT047="HTML";
+$TEXT048="Texto Introductorio";
+$TEXT049="Si estas editando una noticia muy larga, quedar&aacute; mejor si la divides en dos partes.<br>".
+         "Utiliza el cuadro de edici&oacute;n \"$TEXT048\" para introducirla y el cuadro \"$TEXT016\" para el resto.";
 $TEXT050="Leer m&aacute;s";
 $TEXT051="palabras";
 $TEXT052="$TITLE RSS 2.0 Feeds ";
 $TEXT053="Subscribete a los feeds de $TITLE. Actualmente, estan disponibles los siguientes canales de noticias:";
-$TEXT054="Todos los feeds de esta web han sido comprobados usando";
+$TEXT054="<br>No tienes permisos suficientes para editar noticias de otros usuarios!<br><br>".
+         "Si deseas llegar a ser editor, env&iacute;a un email al administrador del site.<br>&nbsp;";
+$TEXT055="<br>No tienes permisos suficientes para borrar noticias !<br><br>".
+         "Si deseas llegar a ser editor, env&iacute;a un email al administrador del site.<br>&nbsp;";
+$TEXT056="Todos los feeds de esta web han sido comprobados usando";
+$TEXT057="Escribe aqu&iacute; tu comentario !";
+$TEXT058="Escribe aqu&iacute; tu text !";
 ?>
